Mixed-up code Questions
-----------------------

.. selectquestion:: itr_countup_str_sq
   :fromid: itr_countup_str_muc, itr_countup_str_ac
   :toggle:

.. selectquestion:: itr_reverse_sq
   :fromid: itr_reverse_muc, itr_reverse_ac
   :toggle:


.. selectquestion:: itr_countdown_str_sq
   :fromid: itr_countdown_str_muc, itr_countdown_str_ac
   :toggle:

.. selectquestion:: itr_odd_sum_sq_v2
   :fromid: itr_odd_sum_muc, itr_odd_sum_ac_v2
   :toggle:

.. selectquestion:: itr_sum_of_range_sq
   :fromid: itr_sum_of_range_muc, itr_sum_of_range_ac
   :toggle:

.. selectquestion:: itr_count_vowels_sq
   :fromid: itr_count_vowels_muc, itr_count_vowels_ac
   :toggle:

.. selectquestion:: itr_copy_till_gt_value_sq
   :fromid: itr_copy_till_gt_value_muc, itr_copy_till_gt_value_ac
   :toggle:

.. selectquestion:: itr_count_last2_sq
   :fromid: itr_count_last2_muc, itr_count_last2_ac
   :toggle:

.. selectquestion:: itr_list_to_5_sq
   :fromid: itr_list_to_5_muc, itr_list_to_5_ac
   :toggle:

.. selectquestion:: itr_water_quality_sq
   :fromid: itr_water_quality_muc, itr_water_quality_ac
   :toggle:
